# Intel

The {py:mod}`torii.platform.vendor.gowin` module provides a base platform to support Gowin FPGAs with the [Gowin] and [Apicula] toolchains.

```{eval-rst}

.. autoclass:: torii.platform.vendor.gowin.GowinPlatform

```


[Gowin]: https://www.gowinsemi.com/en/support/home
[Apicula]: https://github.com/YosysHQ/apicula
